Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2640)

Unified Diff: content/public/test/test_launcher_utils.h

Issue 10984040: Enable gpu crash tests in content (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: refine Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/test/browser_test_base.cc ('k') | content/public/test/test_launcher_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/test/test_launcher_utils.h
diff --git a/chrome/test/base/test_launcher_utils.h b/content/public/test/test_launcher_utils.h
similarity index 64%
copy from chrome/test/base/test_launcher_utils.h
copy to content/public/test/test_launcher_utils.h
index 26c5125a708ac74ed0a0b8ed066b8a2c675186e4..013d576b63e9486d0ef6af784b2ee84eb981fa7e 100644
--- a/chrome/test/base/test_launcher_utils.h
+++ b/content/public/test/test_launcher_utils.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_TEST_BASE_TEST_LAUNCHER_UTILS_H_
-#define CHROME_TEST_BASE_TEST_LAUNCHER_UTILS_H_
+#ifndef CONTENT_PUBLIC_TEST_TEST_LAUNCHER_UTILS_H_
+#define CONTENT_PUBLIC_TEST_TEST_LAUNCHER_UTILS_H_
#include <string>
@@ -13,15 +13,12 @@
class CommandLine;
// A set of utilities for test code that launches separate processes.
-namespace test_launcher_utils {
+namespace content {
-// Appends browser switches to provided |command_line| to be used
-// when running under tests.
+// Appends content switches to provided |command_line| to be used
+// when running under BrowserTestBase.
void PrepareBrowserCommandLineForTests(CommandLine* command_line);
-// Overrides the current process' user data dir.
-bool OverrideUserDataDir(const FilePath& user_data_dir) WARN_UNUSED_RESULT;
-
// Override the GL implementation. The names are the same as for the --use-gl
// command line switch. Use the constants in the gfx namespace.
bool OverrideGLImplementation(
@@ -30,4 +27,4 @@ bool OverrideGLImplementation(
} // namespace test_launcher_utils
-#endif // CHROME_TEST_BASE_TEST_LAUNCHER_UTILS_H_
+#endif // CONTENT_PUBLIC_TEST_TEST_LAUNCHER_UTILS_H_
« no previous file with comments | « content/public/test/browser_test_base.cc ('k') | content/public/test/test_launcher_utils.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698